import(R6)
import(Rcpp)
import(foreach)
import(doParallel)
importFrom(stats, predict)
importFrom(stats, family)
importFrom("stats", "model.matrix")
importFrom(utils, txtProgressBar)
export(Model)
export(cross_val_score)
export(formula_to_matrix)
export(matrix_to_formula)
export(train_test_split)
export(benchmark)
export(extract_probabilities)